==> 1.7-25.10.11.tar.gz: 1.7/load.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

def load():
	## datei laden
	#--------------------
	datei_map = open("map.txt","r",1)
	
	monde = []
	for line in datei_map.readlines():
		tmp = line.split("{")
		i=0
		for e in tmp:
			e= e.strip("}")
			f = e.split(";")
			if f != []:
				monde.append({})
				for g in f:
					#print g
					if g != "":
						if g[0:4] == "pos=":
							h=g[4:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["pos"] = h
						elif g[0:6] == 'datei=':
							h=g[6:]
							h=h.strip('"')
							monde[i]["datei"] = h	
						elif g[0:5] == "link=":
							h=g[5:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["link"] = h
						elif g[0:5] == "size=":
							h=g[5:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["size"] = h
						elif g[0:5] == 'type=':
							h=g[5:]
							h=h.strip('"')
							monde[i]["type"] = h	
						elif g[0:6] == 'bauen=':
							h=g[6:]
							h=h.strip('"')
							monde[i]["bauen"] = int(h)	
				i=i+1
	datei_map.close()

	## neues array initialisieren
	#--------------------
	monde2=[]
	k=0
	for j in monde:
		if j != {}:
			if j["pos"][0] > k:
				k =  j["pos"][0]
	
	n=0
	for m in monde:
		if m != {}:
			if m["pos"][1] > n:
				n = m["pos"][1]
	
	
	for each in range (0,k+1):
		monde2.append([])
		for each in range(0,n+1):
			monde2[-1].append([])
	
	## neues array füllen
	#--------------------
	
	for l in monde:
		if l != {}:
			monde2[ l["pos"][0] ][ l["pos"][1] ] = l
	return monde2


def menu_load():
	pass


def load_neu():
	datei_bgr = open("bgruppen.txt","r",1)
	conf=""
	# alle lines in eine var schreiben
	ok = False		# nur zwischen begin[ebjects] und end[objects] suchen
	for line in datei_bgr.readlines():
		if line == "begin[objects]\n":
			ok = True
		if line == "end[objects]\n":
			ok = False
			break
		if ok == True:
			conf=conf+line
		
		
	conf = conf.expandtabs() # alle tab zeichen in spaces umwandels
	neu={}
	while conf.strip("\n").strip() != "":		# es bleiben eventuell noch spaces und line breaks (wenn die nicht verschwinden -> endloschleife)
		o={}	
		i = conf.find("{")	# anfang
		i2 = conf.find("}")	# ende
		item = conf[i+1:i2]	
		item = item.split("\n")
		for e in item:	
			if e != "":
				e= e.split(":")
				e[1] = e[1].strip().strip('"').strip()	# entferne " von den values der optionen
				e[0] = e[0].strip()		# entferne spaces von index der optionen
				o[e[0]] = e[1].strip().strip('"').strip()	
		neu[int(o["type"])] = o			# erstellung von neu (index muss int sein)
		conf = conf[i2+1:]		# decremenierung um {...}

	# types
	for r in neu:
		for r2 in neu[r]:
			# stings bleiben strings
			if neu[r][r2][0] == "[" and neu[r][r2][-1] == "]":		# arrays
				neu[r][r2] = neu[r][r2].strip("[]").split(",")
				neu[r][r2][0] = int(neu[r][r2][0])
				neu[r][r2][1] = int(neu[r][r2][1])
			elif neu[r][r2].isdigit():			# ints
				neu[r][r2] = int(neu[r][r2])

	datei_bgr.close()		# schliesse datei
	return neu


def load_menu_bauen():
	datei_bgr = open("bgruppen.txt","r",1)
	conf=""
	# alle lines in eine var schreiben
	ok = False		# nur zwischen begin[ebjects] und end[objects] suchen
	for line in datei_bgr.readlines():
		if line == "begin[menu_bauen]\n":
			ok = True
		if line == "end[menu_bauen]\n":
			ok = False
			break
		if ok == True:
			conf=conf+line
		
		
	conf = conf.expandtabs() # alle tab zeichen in spaces umwandels
	neu=[]
	while conf.strip("\n").strip() != "":		# es bleiben eventuell noch spaces und line breaks (wenn die nicht verschwinden -> endloschleife)
		o={}
		i = conf.find("{")	# anfang
		i2 = conf.find("}")	# ende
		item = conf[i+1:i2]	
		item = item.split("\n")
		for e in item:	
			if e != "":
				e= e.split(":")
				e[1] = e[1].strip().strip('"').strip()	# entferne " von den values der optionen
				e[0] = e[0].strip()		# entferne spaces von index der optionen
				o[e[0]] = e[1].strip().strip('"').strip()	
		neu.append(o)			# erstellung von neu (index muss int sein)
		conf = conf[i2+1:]		# decremenierung um {...}

	# types
	for r in neu:
		for r2 in r:
			# stings bleiben strings
			if r[r2][0] == "[" and r[r2][-1] == "]":		# arrays
				r[r2] = r[r2].strip("[]").split(",")
				r[r2][0] = int(r[r2][0])
				r[r2][1] = int(r[r2][1])
			elif r[r2].isdigit():			# ints
				r[r2] = int(r[r2])

	datei_bgr.close()		# schliesse datei
	return neu

==> 1.8-02.11.11.tar.gz: 1.8/load.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

######################################################
###		lADEN								
######################################################
#		LOAD()
#===================================
def load():
	## datei laden
	#--------------------
	datei_map = open("map.txt","r",1)
	
	monde = []
	for line in datei_map.readlines():
		tmp = line.split("{")
		i=0
		for e in tmp:
			e= e.strip("}")
			f = e.split(";")
			if f != []:
				monde.append({})
				for g in f:
					#print g
					if g != "":
						if g[0:4] == "pos=":
							h=g[4:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["pos"] = h
						elif g[0:6] == 'datei=':
							h=g[6:]
							h=h.strip('"')
							monde[i]["datei"] = h	
						elif g[0:5] == "link=":
							h=g[5:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["link"] = h
						elif g[0:5] == "size=":
							h=g[5:]
							h=h.strip("()")
							h=h.split(",")
							h[0]=int(h[0])
							h[1]=int(h[1])
							monde[i]["size"] = h
						elif g[0:5] == 'type=':
							h=g[5:]
							h=h.strip('"')
							monde[i]["type"] = h	
						elif g[0:6] == 'bauen=':
							h=g[6:]
							h=h.strip('"')
							monde[i]["bauen"] = int(h)	
				i=i+1
	datei_map.close()

	## neues array initialisieren
	#--------------------
	monde2=[]
	k=0
	for j in monde:
		if j != {}:
			if j["pos"][0] > k:
				k =  j["pos"][0]
	
	n=0
	for m in monde:
		if m != {}:
			if m["pos"][1] > n:
				n = m["pos"][1]
	
	
	for each in range (0,k+1):
		monde2.append([])
		for each in range(0,n+1):
			monde2[-1].append([])
	
	## neues array füllen
	#--------------------
	
	for l in monde:
		if l != {}:
			monde2[ l["pos"][0] ][ l["pos"][1] ] = l
	return monde2

#		MENU LOAD
#===================================
def menu_load():
	pass

#		LOAD NEU
#===================================
def load_neu():
	datei_bgr = open("bgruppen.txt","r",1)
	conf=""
	# alle lines in eine var schreiben
	ok = False		# nur zwischen begin[ebjects] und end[objects] suchen
	for line in datei_bgr.readlines():
		if line == "begin[objects]\n":
			ok = True
		if line == "end[objects]\n":
			ok = False
			break
		if ok == True:
			conf=conf+line
		
		
	conf = conf.expandtabs() # alle tab zeichen in spaces umwandels
	neu={}
	while conf.strip("\n").strip() != "":		# es bleiben eventuell noch spaces und line breaks (wenn die nicht verschwinden -> endloschleife)
		o={}	
		i = conf.find("{")	# anfang
		i2 = conf.find("}")	# ende
		item = conf[i+1:i2]	
		item = item.split("\n")
		for e in item:	
			if e != "":
				e= e.split(":")
				e[1] = e[1].strip().strip('"').strip()	# entferne " von den values der optionen
				e[0] = e[0].strip()		# entferne spaces von index der optionen
				o[e[0]] = e[1].strip().strip('"').strip()	
		neu[int(o["type"])] = o			# erstellung von neu (index muss int sein)
		conf = conf[i2+1:]		# decremenierung um {...}

	# types
	for r in neu:
		for r2 in neu[r]:
			# stings bleiben strings
			if neu[r][r2][0] == "[" and neu[r][r2][-1] == "]":		# arrays
				neu[r][r2] = neu[r][r2].strip("[]").split(",")
				neu[r][r2][0] = int(neu[r][r2][0])
				neu[r][r2][1] = int(neu[r][r2][1])
			elif neu[r][r2].isdigit():			# ints
				neu[r][r2] = int(neu[r][r2])

	datei_bgr.close()		# schliesse datei
	return neu

#		LOAD MENU BAUEN
#===================================
def load_menu_bauen():
	datei_bgr = open("bgruppen.txt","r",1)
	conf=""
	# alle lines in eine var schreiben
	ok = False		# nur zwischen begin[ebjects] und end[objects] suchen
	for line in datei_bgr.readlines():
		if line == "begin[menu_bauen]\n":
			ok = True
		if line == "end[menu_bauen]\n":
			ok = False
			break
		if ok == True:
			conf=conf+line
		
		
	conf = conf.expandtabs() # alle tab zeichen in spaces umwandels
	neu=[]
	while conf.strip("\n").strip() != "":		# es bleiben eventuell noch spaces und line breaks (wenn die nicht verschwinden -> endloschleife)
		o={}
		i = conf.find("{")	# anfang
		i2 = conf.find("}")	# ende
		item = conf[i+1:i2]	
		item = item.split("\n")
		for e in item:	
			if e != "":
				e= e.split(":")
				e[1] = e[1].strip().strip('"').strip()	# entferne " von den values der optionen
				e[0] = e[0].strip()		# entferne spaces von index der optionen
				o[e[0]] = e[1].strip().strip('"').strip()	
		neu.append(o)			# erstellung von neu (index muss int sein)
		conf = conf[i2+1:]		# decremenierung um {...}

	# types
	for r in neu:
		for r2 in r:
			# stings bleiben strings
			if r[r2][0] == "[" and r[r2][-1] == "]":		# arrays
				r[r2] = r[r2].strip("[]").split(",")
				r[r2][0] = int(r[r2][0])
				r[r2][1] = int(r[r2][1])
			elif r[r2].isdigit() or (r[r2][0] == "-" and r[r2][1:].isdigit()):			# ints
				r[r2] = int(r[r2])

	datei_bgr.close()		# schliesse datei
	return neu


######################################################
###		SPEICHERN								
######################################################
def save(monde):
	world = monde
	datei_map = open("map.txt","w",1)
	for col in world:
		for obj in col:
			posstr = "pos=(" + str(obj["pos"][0]) + "," + str(obj["pos"][1]) + ");"
			if obj.get("link") != None:
				dateistr='link=('+ str(obj["link"][0]) + "," + str(obj["link"][1]) +')'
				sizestr=""
				typestr=""
				bauenstr=""
			else:
				dateistr = 'datei="' + obj["datei"][:-9] + "-z2-n.png" + '";'
				sizestr= "size=("+ str(obj["size"][0]) + "," + str(obj["size"][1]) +');'
				typestr= "type="+ str(obj["type"]) + ";"
				bauenstr="bauen="+str(obj["bauen"])
			save = "{" + posstr + dateistr + sizestr + typestr + bauenstr+"}"
			datei_map.write(save)
	print "world saved to file"
	datei_map.close()
